HIRISE_api.preprocessing.utils — HIRISE_api documentation

# HIRISE_api.preprocessing.utils

Functions

`create_image_list`(file_path[, transform]) | Function that creates a list of all the images in the specified folder in a PIL format
`display_all_images`(file_path, ...[, ...]) | Function to display all the image in the folder in a flat rasterfied format.
`display_image_distributions`(image_file_path, ...) | Function to display all the image in the folder as images on a distributed map using TSNE,UMAP or PCA as the preprocessing function
`normalize_results`(encoded_samples) | Function that is used to normalize the values of the encoded samples.
`read_encoded_csv`(file_path[, autoencoder]) |
`show_cluster_images`(image_file_path, ...[, ...]) | Prints the image in a specified cluster, in the form of a grid with rows and columns specified by the user